@@ -43,7 +43,9 @@ sub add_install_dir {
     
     $self->{config}->{build_dirs} ||= [];
     push(@{$self->{config}->{build_dirs}}, $from);
-    $self->{properties}{install_path}->{$from} = $to;
+    
+    $self->{properties}{install_path}->{$from} ||=
+        $self->default_install_dir("site", $from, $to);
     
     return $to;
 }
